@@ -4,7 +4,6 @@ from __future__ import absolute_import
 
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
-from bitmovin_api_sdk.encoding.infrastructure.kubernetes.kubernetes_api import KubernetesApi
 from bitmovin_api_sdk.encoding.infrastructure.aws.aws_api import AwsApi
 from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ips_api import StaticIpsApi
 from bitmovin_api_sdk.encoding.infrastructure.azure.azure_api import AzureApi
@@ -24,13 +23,6 @@ class InfrastructureApi(BaseApi):
             logger=logger
         )
 
-        self.kubernetes = KubernetesApi(
-            api_key=api_key,
-            tenant_org_id=tenant_org_id,
-            base_url=base_url,
-            logger=logger
-        )
-
         self.aws = AwsApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
