@@ -39,6 +39,7 @@ class AnalyticsAttribute(Enum):
     ERROR_MESSAGE = "ERROR_MESSAGE"
     ERROR_RATE = "ERROR_RATE"
     EXPERIMENT_NAME = "EXPERIMENT_NAME"
+    FUNCTION = "FUNCTION"
     HOUR = "HOUR"
     INITIAL_TIME_TO_TARGET_LATENCY = "INITIAL_TIME_TO_TARGET_LATENCY"
     IP_ADDRESS = "IP_ADDRESS"
@@ -68,6 +69,7 @@ class AnalyticsAttribute(Enum):
     PLAYER_TECH = "PLAYER_TECH"
     PLAYER_VERSION = "PLAYER_VERSION"
     PROG_URL = "PROG_URL"
+    REBUFFER_PERCENTAGE = "REBUFFER_PERCENTAGE"
     REGION = "REGION"
     SCALE_FACTOR = "SCALE_FACTOR"
     SCREEN_HEIGHT = "SCREEN_HEIGHT"
